@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use Dist::Zilla;
 
@@ -333,7 +333,6 @@ sub _build_plugins {
         qw(
             PodSyntaxTests
             Test::CPAN::Changes
-            Test::Compile
             Test::EOL
             Test::NoTabs
             Test::Pod::LinkCheck
@@ -342,6 +341,7 @@ sub _build_plugins {
             Test::Synopsis
             Test::TidyAll
             ),
+        [ 'Test::Compile' => { xt_mode => 1 } ],
 
         # from @Git - note that the order here is important!
         [ 'Git::Check' => { allow_dirty => \@allow_dirty }, ],
@@ -455,7 +455,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =for Pod::Coverage .*
 
